EXPORTS
	_ZN5RSADBC1Ev @ 1 NONAME ; RSADB::RSADB(void)
	_ZN13TPfkeyRecvMsg13BytesUnparsedEv @ 2 NONAME ; TPfkeyRecvMsg::BytesUnparsed(void)
	_ZN5RSADB10CancelRecvEv @ 3 NONAME ; RSADB::CancelRecv(void)
	_ZN5RSADB5CloseEv @ 4 NONAME ; RSADB::Close(void)
	_ZN5RSADB15FinalizeAndSendER17TPfkeySendMsgBaseR14TRequestStatus @ 5 NONAME ; RSADB::FinalizeAndSend(TPfkeySendMsgBase&, TRequestStatus&)
	_ZN17TPfkeySendMsgBase8FinalizeEv @ 6 NONAME ; TPfkeySendMsgBase::Finalize(void)
	_ZN13TPfkeyRecvMsg13NextExtensionER12TPfkeyAnyExt @ 7 NONAME ; TPfkeyRecvMsg::NextExtension(TPfkeyAnyExt&)
	_ZN5RSADB4OpenER11RSocketServ @ 8 NONAME ; RSADB::Open(RSocketServ&)
	_ZN5RSADB11ReadRequestER5TDes8R14TRequestStatus @ 9 NONAME ; RSADB::ReadRequest(TDes8&, TRequestStatus&)
	_ZN13TPfkeyRecvMsg5ResetEv @ 10 NONAME ; TPfkeyRecvMsg::Reset(void)
	_ZN17TPfkeySendMsgBase5ResetEhhii @ 11 NONAME ; TPfkeySendMsgBase::Reset(unsigned char, unsigned char, int, int)
	_ZN5RSADB11SendRequestERK6TDesC8R14TRequestStatus @ 12 NONAME ; RSADB::SendRequest(TDesC8 const&, TRequestStatus&)
	_ZN5RSADBD1Ev @ 13 NONAME ; RSADB::~RSADB(void)
	_ZN11TPfkeyExtSAC1Emhhhhm @ 14 NONAME ; TPfkeyExtSA::TPfkeyExtSA(unsigned long, unsigned char, unsigned char, unsigned char, unsigned char, unsigned long)
	_ZN12TPfkeyExtKeyC1ERK6TDesC8th @ 15 NONAME ; TPfkeyExtKey::TPfkeyExtKey(TDesC8 const&, unsigned short, unsigned char)
	_ZN13TPfkeyRecvMsgC1Ev @ 16 NONAME ; TPfkeyRecvMsg::TPfkeyRecvMsg(void)
	_ZN13TPfkeyRecvMsgC1ERK6TDesC8 @ 17 NONAME ; TPfkeyRecvMsg::TPfkeyRecvMsg(TDesC8 const&)
	_ZN14TPfkeyExtIdentC1ERK6TDesC8tt @ 18 NONAME ; TPfkeyExtIdent::TPfkeyExtIdent(TDesC8 const&, unsigned short, unsigned short)
	_ZN16TPfkeyExtAddressC1ERK9TInetAddrhhh @ 19 NONAME ; TPfkeyExtAddress::TPfkeyExtAddress(TInetAddr const&, unsigned char, unsigned char, unsigned char)
	_ZN16TPfkeyExtPrivateC1ERK6TDesC8 @ 20 NONAME ; TPfkeyExtPrivate::TPfkeyExtPrivate(TDesC8 const&)
	_ZN17TPfkeyExtLifetimeC1EmRKxS1_S1_RKt @ 21 NONAME ; TPfkeyExtLifetime::TPfkeyExtLifetime(unsigned long, long long const&, long long const&, long long const&, unsigned short const&)
	_ZN17TPfkeyExtSpirangeC1Emm @ 22 NONAME ; TPfkeyExtSpirange::TPfkeyExtSpirange(unsigned long, unsigned long)
	_ZN17TPfkeySendMsgBaseC1Ev @ 23 NONAME ; TPfkeySendMsgBase::TPfkeySendMsgBase(void)
	_ZN17TPfkeySendMsgBaseC1Ehhii @ 24 NONAME ; TPfkeySendMsgBase::TPfkeySendMsgBase(unsigned char, unsigned char, int, int)
	_ZN17TPfkeySendMsgBase6AddExtERK12TPfkeyAnyExtRK6TDesC8 @ 25 NONAME ; TPfkeySendMsgBase::AddExt(TPfkeyAnyExt const&, TDesC8 const&)
	_ZN5RSADB10CancelSendEv @ 26 NONAME ; RSADB::CancelSend(void)
	_ZN17TPfkeySendMsgBaseC2Ehhii @ 27 NONAME ; TPfkeySendMsgBase::TPfkeySendMsgBase[not-in-charge](unsigned char, unsigned char, int, int)
	_ZN17TPfkeySendMsgBaseC2Ev @ 28 NONAME ; TPfkeySendMsgBase::TPfkeySendMsgBase[not-in-charge](void)
	_ZN16TPfkeyExtAddressC2ERK9TInetAddrhhh @ 29 NONAME ; TPfkeyExtAddress::TPfkeyExtAddress[not-in-charge](TInetAddr const&, unsigned char, unsigned char, unsigned char)
	_ZN13TPfkeyRecvMsgC2ERK6TDesC8 @ 30 NONAME ; TPfkeyRecvMsg::TPfkeyRecvMsg[not-in-charge](TDesC8 const&)
	_ZN13TPfkeyRecvMsgC2Ev @ 31 NONAME ; TPfkeyRecvMsg::TPfkeyRecvMsg[not-in-charge](void)
	_ZN17TPfkeyExtSpirangeC2Emm @ 32 NONAME ; TPfkeyExtSpirange::TPfkeyExtSpirange[not-in-charge](unsigned long, unsigned long)
	_ZN11TPfkeyExtSAC2Emhhhhm @ 33 NONAME ; TPfkeyExtSA::TPfkeyExtSA[not-in-charge](unsigned long, unsigned char, unsigned char, unsigned char, unsigned char, unsigned long)
	_ZN16TPfkeyExtPrivateC2ERK6TDesC8 @ 34 NONAME ; TPfkeyExtPrivate::TPfkeyExtPrivate[not-in-charge](TDesC8 const&)
	_ZN12TPfkeyExtKeyC2ERK6TDesC8th @ 35 NONAME ; TPfkeyExtKey::TPfkeyExtKey[not-in-charge](TDesC8 const&, unsigned short, unsigned char)
	_ZN17TPfkeyExtLifetimeC2EmRKxS1_S1_RKt @ 36 NONAME ; TPfkeyExtLifetime::TPfkeyExtLifetime[not-in-charge](unsigned long, long long const&, long long const&, long long const&, unsigned short const&)
	_ZN5RSADBC2Ev @ 37 NONAME ; RSADB::RSADB[not-in-charge](void)
	_ZN14TPfkeyExtIdentC2ERK6TDesC8tt @ 38 NONAME ; TPfkeyExtIdent::TPfkeyExtIdent[not-in-charge](TDesC8 const&, unsigned short, unsigned short)
	_ZN5RSADBD2Ev @ 39 NONAME ; RSADB::~RSADB [not-in-charge](void)
	_ZN22TPfkeyExtNamedEndPointC1ERK6TDesC8t @ 40 NONAME
	_ZN22TPfkeyExtNamedEndPointC2ERK6TDesC8t @ 41 NONAME
	_ZN24TPfkeyExtTrafficSelectorC1Em @ 42 NONAME
	_ZN24TPfkeyExtTrafficSelectorC2Em @ 43 NONAME
	_ZN5RSADB6SetOptEjjRK6TDesC8 @ 44 NONAME

